summaryrefslogtreecommitdiff
path: root/expt_0406.cu
diff options
context:
space:
mode:
Diffstat (limited to 'expt_0406.cu')
-rw-r--r--expt_0406.cu4
1 files changed, 2 insertions, 2 deletions
diff --git a/expt_0406.cu b/expt_0406.cu
index 30ee7c4..4e9ec89 100644
--- a/expt_0406.cu
+++ b/expt_0406.cu
@@ -56,8 +56,8 @@ __global__ void kernel(unsigned long step, const double slice_size) {
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
// printf("%d\n", tid);
- auto index = (int)(FactorySort::sample_cdf(cudaSampleItem, length,
- cudaPopulationItem[tid]) /
+ auto index = (int)(FactorySort::cdf(cudaSampleItem, length,
+ cudaPopulationItem[tid]) /
slice_size);
cdf_result[index] = true;